# Credits

## Contributors

* Nouamane Arhachoui <[nouamane.arhachoui@lip6.fr](mailto:nouamane.arhachoui@lip6.fr)>
* Esteban Bautista <[esteban.bautista-ruiz@lip6.fr](mailto:esteban.bautista-ruiz@lip6.fr)>
* Anastasios Giovanidis <[anastasios.giovanidis@lip6.fr](mailto:anastasios.giovanidis@lip6.fr)>
